@@ -1,4 +1,5 @@
 ### R code from vignette source 'protViz.Rnw'
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: protViz.Rnw:39-40
@@ -7,38 +8,47 @@ options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)
 
 
 ###################################################
-### code chunk number 2: protViz.Rnw:128-148
+### code chunk number 2: protViz.Rnw:85-88
 ###################################################
 library(protViz)
-op<-par(mfrow=c(1,1))
-fetuin<-c('MK', 'SFVLLFCLAQLWGCHSIPLDPVAGYK',
-'EPACDDPDTEQAALAAVDYINK',
-'HLPR', 'GYK', 'HTLNQIDSVK', 'VWPR', 
-'RPTGEVYDIEIDTLETTCHVLDPTPLANCSVR',
-'QQTQHAVEGDCDIHVLK', 'QDGQFSVLFTK',
-'CDSSPDSAEDVR', 'K', 'LCPDCPLLAPLNDSR',
-'VVHAVEVALATFNAESNGSYLQLVEISR',
-'AQFVPLPVSVSVEFAVAATDCIAK',
-'EVVDPTK', 'CNLLAEK', 'QYGFCK',
-'GSVIQK', 'ALGGEDVR', 
-'VTCTLFQTQPVIPQPQPDGAEAEAPSAVPDAAGPTPSAAGPPVASVVVGPSVVAVPLPLHR',
-'AHYDLR', 'HTFSGVASVESSSGEAFHVGK',
-'TPIVGQPSIPGGPVR', 'LCPGR', 'IR', 'YFK', 'I')
-(pm <- parentIonMass(fetuin))
-op <- par(mfrow=c(2,1))
-plot(pm, ylab="peptide mass [in Da]", 
-    main="Fetuin Peptide tryptic digested.")
-hist(pm, xlab="peptide mass [in Da]")
+fname <- system.file("extdata", name='P12763.fasta', package = "protViz")
+F <- Fasta$new(fname)
 
 
 ###################################################
-### code chunk number 3: protViz.Rnw:157-158
+### code chunk number 3: protViz.Rnw:92-93
+###################################################
+substr(F$getSequences(), 1, 60)
+
+
+###################################################
+### code chunk number 4: protViz.Rnw:96-97
+###################################################
+F$getTrypticPeptides()
+
+
+###################################################
+### code chunk number 5: protViz.Rnw:106-115
+###################################################
+op <- par(mfrow = c(1,1))
+fetuin <- F$getTrypticPeptides()
+(pm <- parentIonMass(fetuin))
+op <- par(mfrow = c(2, 1))
+plot(pm, 
+    ylab = "peptide mass [in Da]", 
+    main = "Fetuin Peptide tryptic digested.")
+hist(pm, 
+     xlab = "peptide mass [in Da]")
+
+
+###################################################
+### code chunk number 6: protViz.Rnw:124-125
 ###################################################
 defaultIon
 
 
 ###################################################
-### code chunk number 4: protViz.Rnw:161-186
+### code chunk number 7: protViz.Rnw:128-153
 ###################################################
 peptides<-c('HTLNQIDSVK', 'ALGGEDVR', 'TPIVGQPSIPGGPVR')
 
@@ -68,7 +78,7 @@ for (i in 1:length(peptides)){
 
 
 ###################################################
-### code chunk number 5: protViz.Rnw:190-193
+### code chunk number 8: protViz.Rnw:157-160
 ###################################################
 Hydrogen<-1.007825
 (fi.HTLNQIDSVK.1 <- fragmentIon('HTLNQIDSVK'))[[1]]
@@ -76,7 +86,7 @@ Hydrogen<-1.007825
 
 
 ###################################################
-### code chunk number 6: protViz.Rnw:207-246
+### code chunk number 9: protViz.Rnw:174-213
 ###################################################
     peptideSequence<-'HTLNQIDSVK'
     spec<-list(scans=1138,
@@ -120,7 +130,7 @@ Hydrogen<-1.007825
 
 
 ###################################################
-### code chunk number 7: protViz.Rnw:252-282
+### code chunk number 10: protViz.Rnw:219-249
 ###################################################
 library(protViz)
 
@@ -155,7 +165,7 @@ fi <- fragmentIon(c('TAFDEAIAELDTLSEESYK',
 
 
 ###################################################
-### code chunk number 8: protViz.Rnw:290-295
+### code chunk number 11: protViz.Rnw:257-262
 ###################################################
 data(msms)
 op <- par(mfrow=c(2,1))
@@ -165,7 +175,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 9: protViz.Rnw:304-333
+### code chunk number 12: protViz.Rnw:271-300
 ###################################################
 peptideSearch <- function (x, 
                            peptideSequence, 
@@ -199,7 +209,7 @@ peptideSearch <- function (x,
 
 
 ###################################################
-### code chunk number 10: protViz.Rnw:351-383
+### code chunk number 13: protViz.Rnw:318-350
 ###################################################
 library(lattice)
 data(fetuinLFQ)
@@ -236,7 +246,7 @@ print(xyplot(abundance~conc|prot*method,
 
 
 ###################################################
-### code chunk number 11: protViz.Rnw:395-420
+### code chunk number 14: protViz.Rnw:362-387
 ###################################################
 data(pgLFQfeature)
 data(pgLFQprot)
@@ -266,7 +276,7 @@ featureDensityPlot(asinh(pgLFQfeature$"Normalized abundance"),
 
 
 ###################################################
-### code chunk number 12: protViz.Rnw:426-440
+### code chunk number 15: protViz.Rnw:393-407
 ###################################################
 op<-par(mfrow=c(1,1),mar=c(18,18,4,1),cex=0.5)
 samples<-names(pgLFQfeature$"Normalized abundance")
@@ -285,7 +295,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 13: protViz.Rnw:445-455
+### code chunk number 16: protViz.Rnw:412-422
 ###################################################
 op<-par(mfrow=c(1,1),mar=c(18,18,4,1),cex=0.5)
 image(cor(asinh(pgLFQprot$"Normalized abundance")),
@@ -300,7 +310,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 14: protViz.Rnw:462-468
+### code chunk number 17: protViz.Rnw:429-435
 ###################################################
 par(mfrow=c(2,2),mar=c(6,3,4,1))
 ANOVA<-pgLFQaov(pgLFQprot$"Normalized abundance", 
@@ -311,7 +321,7 @@ ANOVA<-pgLFQaov(pgLFQprot$"Normalized abundance",
 
 
 ###################################################
-### code chunk number 15: protViz.Rnw:479-488
+### code chunk number 18: protViz.Rnw:446-455
 ###################################################
 data(iTRAQ)
 x<-rnorm(100)
@@ -325,7 +335,7 @@ b<-boxplot(asinh(iTRAQ[,c(3:10)]), main='boxplot iTRAQ')
 
 
 ###################################################
-### code chunk number 16: protViz.Rnw:495-528
+### code chunk number 19: protViz.Rnw:462-495
 ###################################################
 data(iTRAQ)
 group1Protein<-numeric()
@@ -363,7 +373,7 @@ for (i in 1:nrow(group1Protein)){
 
 
 ###################################################
-### code chunk number 17: protViz.Rnw:537-544
+### code chunk number 20: protViz.Rnw:504-511
 ###################################################
 data(iTRAQ)
 q<-iTRAQ2GroupAnalysis(data=iTRAQ, 
@@ -375,14 +385,14 @@ q[1:10,]
 
 
 ###################################################
-### code chunk number 18: protViz.Rnw:555-557
+### code chunk number 21: protViz.Rnw:522-524
 ###################################################
 data(pressureProfile)
 ppp(pressureProfile)
 
 
 ###################################################
-### code chunk number 19: protViz.Rnw:566-582
+### code chunk number 22: protViz.Rnw:533-549
 ###################################################
 pp.data<-pps(pressureProfile, time=seq(25,40,by=5))
 print(xyplot(Pc ~ as.factor(file) | paste("time =", 
@@ -403,7 +413,7 @@ print(xyplot(Pc ~ as.factor(file) | paste("time =",
 
 
 ###################################################
-### code chunk number 20: protViz.Rnw:587-592
+### code chunk number 23: protViz.Rnw:554-559
 ###################################################
 pp.data<-pps(pressureProfile, time=seq(0,140,length=128))
 print(levelplot(Pc ~ time * as.factor(file),
@@ -413,7 +423,7 @@ print(levelplot(Pc ~ time * as.factor(file),
 
 
 ###################################################
-### code chunk number 21: protViz.Rnw:601-603
+### code chunk number 24: protViz.Rnw:568-570
 ###################################################
 sessionInfo()
 packageDescription('protViz')
